# Tests

## Preparation

Prepare PostgreSQL user so PeerTube can delete/create the test databases:

```bash
sudo -u postgres createuser you_username --createdb --superuser
```

Prepare the databases:

```bash
npm run clean:server:test
```

Build PeerTube:

```bash
npm run build
```

## Server tests

### Dependencies

Run docker containers needed by some test files:

```bash
sudo docker run -p 9444:9000 chocobozzz/s3-ninja
sudo docker run -p 10389:10389 chocobozzz/docker-test-openldap
```

Ensure you also have these commands:

```bash
exiftool --help
parallel --help

# For transcription tests
whisper --help
whisper-ctranslate2 --help
jiwer --help
```

Otherwise, install the packages. On Debian-based systems (like Debian, Ubuntu or Mint):
```bash
sudo apt-get install parallel libimage-exiftool-perl
sudo pip install -r packages/tests/requirements.txt -r packages/transcription-devtools/requirements.txt
```

### Test

To run all test suites (can be long!):

```bash
npm run test # See scripts/test.sh to run a particular suite
```

To run a specific test:

```bash
npm run mocha -- --exit --bail packages/tests/src/your-test.ts

# For example
npm run mocha -- --exit --bail packages/tests/src/api/videos/single-server.ts
```

### Configuration

Some env variables can be defined to disable/enable some tests:
Some env variables can be defined to disable/enable some tests:

 * `DISABLE_HTTP_IMPORT_TESTS=true`: disable import tests (because of youtube that could rate limit your IP)
 * `DISABLE_HTTP_YOUTUBE_IMPORT_TESTS=true`: disable youtube import tests (because youtube blocks CI server IP)
 * `ENABLE_OBJECT_STORAGE_TESTS=true`: enable object storage tests (needs `chocobozzz/s3-ninja` container first)
 * `AKISMET_KEY`: specify an Akismet key to test akismet external PeerTube plugin
 * `ENABLE_FFMPEG_THUMBNAIL_PIXEL_COMPARISON_TESTS=true`: enable pixel comparison on images generated by ffmpeg. Disabled by default because a custom ffmpeg version may fails the tests
 * `OBJECT_STORAGE_SCALEWAY_KEY_ID` and `OBJECT_STORAGE_SCALEWAY_ACCESS_KEY`: specify Scaleway API keys to test object storage ACL (not supported by our `chocobozzz/s3-ninja` container)
 * `YOUTUBE_DL_DOWNLOAD_BEARER_TOKEN`: bearer token to download youtube-dl binary
 * `YOUTUBE_DL_PROXY`: custom proxy URL for youtube-dl HTTP video import


### Debug server logs

While testing, you might want to display a server's logs to understand why they failed:

```bash
NODE_APP_INSTANCE=1 NODE_ENV=test npm run parse-log -- --level debug | less +GF
```

You can also:
 - checkout only the latest logs (PeerTube >= 5.0):

```bash
tail -n 100 test1/logs/peertube.log | npm run parse-log -- --level debug --files -
```

 - continuously print the latests logs (PeerTube >= 5.0):

```bash
tail -f test1/logs/peertube.log | npm run parse-log -- --level debug --files -
```


## Client E2E tests

### Local tests

To run tests on local web browsers (comment web browsers you don't have in `client/e2e/wdio.local.conf.ts`):

```bash
PEERTUBE2_E2E_PASSWORD=password npm run e2e:local
```

### Browserstack tests

To run tests on browser stack:

```bash
BROWSERSTACK_USER=your_user BROWSERSTACK_KEY=your_key npm run e2e:browserstack
```

### Add E2E tests

To add E2E tests and quickly run tests using a local Chrome:

```bash
cd client/e2e
../node_modules/.bin/wdio wdio.local-test.conf.ts # you can also add --mochaOpts.grep to only run tests you want
```
